@@ -3,11 +3,15 @@
 HttpCtrl library provides HTTP/HTTPS client and server API to Robot Framework to make REST API testing easy.
 
 Authors: Andrei Novikov
-Date: 2018-2021
+Date: 2018-2022
 Copyright: The 3-Clause BSD License
 
 """
 
+
+from HttpCtrl.utils.logger import LoggerAssistant
+
+
 class Response:
     def __init__(self, status, reason, body, headers):
         self.__status = status
@@ -19,7 +23,8 @@ class Response:
         if self.__body is None or len(self.__body) == 0:
             return str(self.__status)
 
-        return "%s\n%s" % (str(self.__status), self.__body)
+        body_to_log = LoggerAssistant.get_body(self.__body)
+        return "%s\n%s" % (str(self.__status), body_to_log)
 
     def __copy__(self):
         return Response(self.__status, self.__reason, self.__body, self.__headers)
